## Copyright (C) 2012 Lorant Oroszlany
## 
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## elc(n,sf,k) returns equal loudness curve for loudness 40 Ph of 
## length n within frequency range 0 - sf/2. k is a constant by which
## all the values are multiplied (default means the values are 
## between 0 and 1). 

## Author: Lorant Oroszlany
## Created: 2012-04-28

function ret = elc (n,sf,k)

O = zeros(n,1);
for i = 1:n
	O(i) = 2*pi*i*sf/(2*n);
end 

r = E(O);
if nargin < 3;
	k = 1/max(E(O));	% constant for normalization
end; 

ret = k.*r;

endfunction

function ret = E(O)

if size(O) == [1,1]
	ret = (O^4*(O^2 + 56.9*10^6)) / ( ((O^2 + 6.3*10^6)^2) * (O^2 + 379.4*10^6) * (O^6 + 9.6*10^26)  );
else
	ret = arrayfun(@E,O);
endif

endfunction