function [S,T] = stacf(X, win_size, inc, win_type, vis)
% S = stacf(X, [win_size, [inc, [win_type, [vis]]]])
%
% Returns the short-time autocorrelation of input signal X
%
% ARGUMENTS (DEFAULT):
%  win_size (160 samples or 10 ms)
%                window size (if X is passed as an 
%                array, win_size is passed in samples, if it is a WAV file, 
%                win_size is passed in milliseconds)
%  inc           number of samples between the centres of two adjacent
%                windows
%  win_type (2)  window type (1 - hamming, 2 - rectangular)
%  vis           (optional) if present and greater than 0, plots a 3d mesh
%                plot of the result

acf = @(x) xcorr(x)(ceil(end/2):end);

if ischar(X) 
	[X,sf,bps] = wavread(X);
	if nargin < 2
		win_size = sf/100; 
	else 
		win_size = ceil(sf*(win_size/1000));
	end
	if nargin < 3
		inc = floor(win_size/2);
	else
		inc = ceil(sf*(inc/1000));
	end
else
	if nargin < 2; win_size = 160;  end;
	if nargin < 3; inc = floor(win_size/2); end;
end
if nargin < 4; win_type = 1; end;
if nargin < 5; vis = -1; end;

if ~isvector(X)
	if columns(X) > rows(X)
		X = X.';
	end
	S = stacf(X(:,1),win_size,inc,win_type,vis);
	if vis >= 0; figure; end;
	T = stacf(X(:,2),win_size,inc,win_type,vis); 
else

	S = stf(X, acf, win_size, inc, win_type, win_size);
	
	if vis > 0;
		mesh(S); view(2); axis('tight'); colorbar('SouthOutside'); title('Short-time autocorrelation function'); xlabel('Window No.'); ylabel('Samples');
	end
	
end
	
end



