## Copyright (C) 2012 Lorant Oroszlany
## 
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## Short-time function
## ret = stf (X, func, win_size, inc, win_type, max_val, varargin)
## Applies function func to windowed slices of signal X
## 
## This function does not use default values, argmuents must be specified 
## explicitly
## ARGUMENTS
##   win_size        window size in samples
##   inc             number of samples between the centres of two adjacent 
##                   windows
##   win_type        window type 1 - hamming 2 - rectangular
##   max_val         the expected lenght of the result for one window
##   varargin        (optional) additional arguments to function func 

## Author: Lorant Oroszlany
## Created: 2012-04-30

function ret = stf (X, func, win_size, inc, win_type, max_val, varargin)

	if nargin < 6; max_val = win_size; end;
	
	if ~is_function_handle(func)
		error('argument func must be a function handle');
	end
	
	switch (win_type)
	case 1 
		win = hamming(win_size);
	case 2 
		win = ones(win_size,1);
	otherwise
		win = hamming(win_size);
	end
	
	blocks = floor((length(X) - win_size) / inc + 1);
	ret = zeros(max_val, blocks);
	
	if length(varargin) > 0
		for i = 0:blocks-1
			ret(:,i+1) = func(X(i*inc+1:i*inc+win_size).*win,varargin{1,:})(1:max_val);
		end;
	else
		for i = 0:blocks-1
			ret(:,i+1) = func(X(i*inc+1:i*inc+win_size).*win)(1:max_val);
		end;
	end

endfunction
