function [S,T] = sti(X, win_size, win_type, nval)
% S = sti(X, [win_size, [win_type, [nval]]])
%
% Computes the short-time intensity of signal X. X can be passed as an
% array of discrete PCM values or as a string containing the path to a .WAV
% file. 
%	
% ARGUMENTS (DEFAULT):
%  win_size (160 samples or 10 ms)
%                window size (if X is passed as an 
%                array, win_size is passed in samples, if it is a WAV file, 
%                win_size is passed in milliseconds)
%  win_type (2)  window type (1 - hamming, 2 - rectangular)
%  nval          if present, plots the short time function and the signal
%                waveform (nonzero value smooths the plot with nval points) 

if ischar(X) 
	[X,sf,bps] = wavread(X);
	if nargin < 2
		win_size = sf/100; 
	else 
		win_size = ceil(sf*(win_size/1000));
	end
else
	if nargin < 2; win_size = 160;  end;
end

if nargin < 3; win_type = 1; end;
if nargin < 4; nval = -1; end;

if ~isvector(X)
	if columns(X) > rows(X)
		X = X.';
	end
	S = sti(X(:,1),win_size,win_type,nval);
	if nval~=-1; figure; end;
	T = sti(X(:,2),win_size,win_type,nval); 
else

	switch (win_type)
	case 1 
		win = hamming(win_size);
	case 2 
		win = ones(win_size,1);
	otherwise
		win = hamming(win_size);
	end

	x1 = abs(X);
	S = conv(x1,win,'same');

	if nval ~= -1;
		plot(X);
		plot_stf(S,nval);
		legend('Waveform','Short-time intensity');
	end

end	

endfunction


