function [S,T] = zcr(X, win_size, nval)
% S = zcr(X, [win_size, nval]])
%
% Computes the short-time zero crossing rate of signal X. X can be passed
% as an array of discrete PCM values or as a string containing the path
% to a .WAV file. 
%	
% ARGUMENTS (DEFAULT):
%   win_size (160 samples or 10 ms)
%             window size (if X is passed as an array, win_size is passed
%             in samples, if it is a WAV file, win_size is passed in 
%             milliseconds)
%   nval      if present, plots the short time function and the signal
%             waveform (nonzero value smooths the plot with nval points) 

if ischar(X) 
	[X,sf,bps] = wavread(X);
	if nargin < 2
		win_size = sf/100; 
	else 
		win_size = sf*(win_size/1000);
	end
else
	if nargin < 2; win_size = 160;  end;
end

if nargin < 3; nval = -1; end;

if ~isvector(X)
	if columns(X) > rows(X)
		X = X.';
	end
	S = zcr(X(:,1),win_size,nval);
	if nval~=-1; figure; end;
	T = zcr(X(:,2),win_size,nval); 
else

	win = ones(win_size,1);
	X = X(:,1);

	x1 = X(1);
	x2 = [0;X(1:end-1)];
	x = abs(sgn(x2) - sgn(x1));
	S = conv(x,win,'same');

	if nval ~= -1;
		plot(X);
		plot_stf(S,nval);
		legend('Waveform','Short-time zero-crossing rate');
	end

end		

endfunction
